@@ -26,7 +26,7 @@ from logging import getLogger
 from gi.repository import Gtk
 from gi.repository import Gdk
 
-from ..base.resources import Resources
+from ..resources import Resources
 from ..util import GladeInterface
 from ..tools import Tool, Job
 
@@ -268,8 +268,10 @@ class ConfigureToolDialog(GladeInterface):
         self._button_add_extension.set_sensitive(len(self._entry_new_extension.get_text()) > 0)
 
     def _on_job_cursor_changed(self, tree_view):
-        store, iter = tree_view.get_selection().get_selected()
-        if not iter:
+        selection = tree_view.get_selection()
+        if selection:
+            store, iter = tree_view.get_selection().get_selected()
+        if not selection or not iter:
             return
         self._button_remove_job.set_sensitive(True)
 
@@ -277,8 +279,10 @@ class ConfigureToolDialog(GladeInterface):
         self._button_job_up.set_sensitive(not first_row_selected)
 
     def _on_extension_cursor_changed(self, tree_view):
-        store, it = tree_view.get_selection().get_selected()
-        if not it:
+        selection = tree_view.get_selection()
+        if selection:
+            store, it = tree_view.get_selection().get_selected()
+        if not selection or not it:
             return
         self._button_remove_extension.set_sensitive(True)
 
@@ -354,9 +358,6 @@ class PreferencesDialog(GladeInterface):
             check_hide_box = self.find_widget("checkHideBox")
             check_hide_box.set_active(self._preferences.get("hide-box-warnings"))
 
-            filechooser_tmp = self.find_widget("filechooserTemplates")
-            filechooser_tmp.set_filename(self._preferences.TEMPLATE_DIR)
-
 
             #
             # proxies for SpinButtons
@@ -375,16 +376,10 @@ class PreferencesDialog(GladeInterface):
                                    "on_buttonMoveDownTool_clicked" : self._on_tool_down_clicked,
                                    "on_buttonConfigureTool_clicked" : self._on_configure_tool_clicked,
                                    "on_buttonDeleteTool_clicked" : self._on_delete_tool_clicked,
-                                   "on_checkHideBox_toggled" : self._on_hide_box_toggled,
-                                   "on_filechooserTemplates_selection_changed" : self._on_templates_dir_changed})
+                                   "on_checkHideBox_toggled" : self._on_hide_box_toggled})
 
         return self._dialog
 
-    def _on_templates_dir_changed(self, filechooser):
-        folder = filechooser.get_filename()
-        if folder is None:
-            return
-
     def _on_hide_box_toggled(self, togglebutton):
         value = togglebutton.get_active()
         self._preferences.set("hide-box-warnings", value)
@@ -394,8 +389,10 @@ class PreferencesDialog(GladeInterface):
 
     def _load_tools(self):
         # save cursor
-        store, iter = self._view_tool.get_selection().get_selected()
-        if iter is None:
+        selection = self._view_tool.get_selection()
+        if selection:
+            store, iter = self._view_tool.get_selection().get_selected()
+        if not selection or iter is None:
             restore_cursor = False
         else:
             path = store.get_path(iter)
@@ -423,7 +420,7 @@ class PreferencesDialog(GladeInterface):
         store, it = self._view_tool.get_selection().get_selected()
         tool = store.get_value(it, 2)
 
-        self._preferences.delete_tool(tool)
+        self._tool_preferences.delete_tool(tool)
 
     def _on_tool_up_clicked(self, button):
         """
@@ -438,7 +435,7 @@ class PreferencesDialog(GladeInterface):
         iter_previous = store.get_iter_from_string(str(index_previous))
         tool_2 = store.get_value(iter_previous, 2)
 
-        self._preferences.swap_tools(tool_1, tool_2)
+        self._tool_preferences.swap_tools(tool_1, tool_2)
 
         # adjust selection
         self._view_tool.get_selection().select_path(str(index_previous))
@@ -483,8 +480,10 @@ class PreferencesDialog(GladeInterface):
         """
         The cursor in the tools view has changed
         """
-        store, it = treeView.get_selection().get_selected()
-        if not it:
+        selection = treeView.get_selection()
+        if selection:
+            store, it = treeView.get_selection().get_selected()
+        if not selection or not it:
             return
 
         self._profile = store.get_value(it, 1)
@@ -493,9 +492,4 @@ class PreferencesDialog(GladeInterface):
         self._button_move_up_tool.set_sensitive(True)
         self._button_configure_tool.set_sensitive(True)
 
-
-
-
-
-
 # ex:ts=4:et:
