@@ -25,7 +25,7 @@ import os
 
 from gi.repository import GObject
 
-from ..base.resources import Resources
+from ..resources import Resources
 from ..tools import Tool, Job
 from ..tools.postprocess import GenericPostProcessor, RubberPostProcessor, LaTeXPostProcessor
 from ..util import singleton
@@ -128,13 +128,13 @@ class ToolPreferences(GObject.GObject):
             # create new tool tag
             LOG.debug("Creating new Tool...")
 
-            id = str(uuit.uuid4())
+            id = unicode(uuid.uuid4())
             self.__tool_ids[tool] = id
 
             tool_element = ElementTree.SubElement(self.__tools, "tool")
             tool_element.set("id", id)
-
-        tool_element.set("label", tool.label)
+        
+        tool_element.set("label", tool.label.decode('utf-8'))
         tool_element.set("description", tool.description)
         tool_element.set("extensions", " ".join(tool.extensions))
         if tool.accelerator is None:
